from themer import ColorParser, check_file_regex
import re

class VimColorParser(ColorParser):
    check = check_file_regex('\.vim$')

    vimGroups = ['Normal', 'Visual', 'VertSplit', 'Identifier', 'Statement', 'PreProc', 'Type', 'Function', 'String', 'Conditional', 'Repeat', 'Label', 'Operator', 'Keyword', 'Exception', 'Character', 'Number', 'Boolean', 'Float', 'Comment', 'Special', 'Error', 'Todo']
    vimGroups.reverse()
    mapping = {
        'bg': ['background', 'black', 'alt_black'],
        'fg': ['foreground', 'white'],
        'rest': ['red', 'alt_red', 'green', 'alt_green', 'yellow', 'alt_yellow', 'blue', 'alt_blue', 'magenta', 'alt_magenta', 'cyan', 'alt_cyan', 'alt_white']
        }

    def mapVimColorNames(self, name):
      #TODO handle unknown names
      for o in vimColorsMapping:
        if o['name'] == name:
          return o['hex']

    def read(self):
      normalBg, normalFg = '', ''
      self.colors = []
      output = {}
      groupRegex = re.compile(r'hi\s(\w*)\s')
      guibgRegex = re.compile(r'guibg\=(\S*)\s')
      guifgRegex = re.compile(r'guifg\=(\S*)\s')
      with open(self.data) as fh:
          for line in fh:
              guifg = guifgRegex.findall(line)
              guibg = guibgRegex.findall(line)
              group = groupRegex.findall(line)
              if(group and (guifg or guibg)):
                  currentLine = {
                          "group": group[0] if group else ''
                          , "fg": guifg[0] if guifg else ''
                          , "bg": guibg[0] if guibg else ''
                          }
                  # normalize each line
                  currentLine.update((x, y.strip().lower()) for x, y in currentLine.items())
                  # store the basic colors ('normal' colors) without any special hi gourps
                  if(currentLine["group"] == "normal"):
                      normalFg = currentLine["fg"]; 
                      normalBg = currentLine["bg"];
                  self.colors.append(currentLine)
          # convert vim color name to hex
          for entry in self.colors:
            if(entry['fg'].find('#')):
              entry['fg'] = self.mapVimColorNames(entry['fg'])
            if(entry['bg'].find('#')):
              entry['bg'] = self.mapVimColorNames(entry['bg'])

          # walk through self colors, check for vim groups of interest - use those for fg,bg, pop through the rest
          for fgtype in self.mapping['fg']:
            output.update({fgtype: normalFg})
          for bgtype in self.mapping['bg']:
            output.update({bgtype: normalBg})
          for el in self.colors:
            for group in self.vimGroups:
              if(len(self.mapping['rest'])>0 and el['group']==group.lower()):
                output.update({self.mapping['rest'].pop(): el['fg']})
          return output

vimColorsMapping = [
    {
      "name":"black",
      "hex":"#000000"
    },
    {
      "name":"gray0",
      "hex":"#000000"
    },
    {
      "name":"grey0",
      "hex":"#000000"
    },
    {
      "name":"gray1",
      "hex":"#030303"
    },
    {
      "name":"grey1",
      "hex":"#030303"
    },
    {
      "name":"gray2",
      "hex":"#050505"
    },
    {
      "name":"grey2",
      "hex":"#050505"
    },
    {
      "name":"gray3",
      "hex":"#080808"
    },
    {
      "name":"grey3",
      "hex":"#080808"
    },
    {
      "name":"navyblue",
      "hex":"#000080"
    },
    {
      "name":"navy blue",
      "hex":"#000080"
    },
    {
      "name":"navy",
      "hex":"#000080"
    },
    {
      "name":"gray4",
      "hex":"#0a0a0a"
    },
    {
      "name":"grey4",
      "hex":"#0a0a0a"
    },
    {
      "name":"darkblue",
      "hex":"#00008b"
    },
    {
      "name":"blue4",
      "hex":"#00008b"
    },
    {
      "name":"dark blue",
      "hex":"#00008b"
    },
    {
      "name":"gray5",
      "hex":"#0d0d0d"
    },
    {
      "name":"grey5",
      "hex":"#0d0d0d"
    },
    {
      "name":"mediumblue",
      "hex":"#0000cd"
    },
    {
      "name":"blue3",
      "hex":"#0000cd"
    },
    {
      "name":"medium blue",
      "hex":"#0000cd"
    },
    {
      "name":"gray6",
      "hex":"#0f0f0f"
    },
    {
      "name":"grey6",
      "hex":"#0f0f0f"
    },
    {
      "name":"blue2",
      "hex":"#0000ee"
    },
    {
      "name":"gray7",
      "hex":"#121212"
    },
    {
      "name":"grey7",
      "hex":"#121212"
    },
    {
      "name":"blue1",
      "hex":"#0000ff"
    },
    {
      "name":"blue",
      "hex":"#0000ff"
    },
    {
      "name":"gray8",
      "hex":"#141414"
    },
    {
      "name":"grey8",
      "hex":"#141414"
    },
    {
      "name":"gray9",
      "hex":"#171717"
    },
    {
      "name":"grey9",
      "hex":"#171717"
    },
    {
      "name":"gray10",
      "hex":"#1a1a1a"
    },
    {
      "name":"grey10",
      "hex":"#1a1a1a"
    },
    {
      "name":"gray11",
      "hex":"#1c1c1c"
    },
    {
      "name":"grey11",
      "hex":"#1c1c1c"
    },
    {
      "name":"darkred",
      "hex":"#8b0000"
    },
    {
      "name":"dark red",
      "hex":"#8b0000"
    },
    {
      "name":"red4",
      "hex":"#8b0000"
    },
    {
      "name":"gray12",
      "hex":"#1f1f1f"
    },
    {
      "name":"grey12",
      "hex":"#1f1f1f"
    },
    {
      "name":"midnightblue",
      "hex":"#191970"
    },
    {
      "name":"midnight blue",
      "hex":"#191970"
    },
    {
      "name":"gray13",
      "hex":"#212121"
    },
    {
      "name":"grey13",
      "hex":"#212121"
    },
    {
      "name":"gray14",
      "hex":"#242424"
    },
    {
      "name":"grey14",
      "hex":"#242424"
    },
    {
      "name":"gray15",
      "hex":"#262626"
    },
    {
      "name":"grey15",
      "hex":"#262626"
    },
    {
      "name":"darkmagenta",
      "hex":"#8b008b"
    },
    {
      "name":"dark magenta",
      "hex":"#8b008b"
    },
    {
      "name":"magenta4",
      "hex":"#8b008b"
    },
    {
      "name":"gray16",
      "hex":"#292929"
    },
    {
      "name":"grey16",
      "hex":"#292929"
    },
    {
      "name":"deeppink4",
      "hex":"#8b0a50"
    },
    {
      "name":"gray17",
      "hex":"#2b2b2b"
    },
    {
      "name":"grey17",
      "hex":"#2b2b2b"
    },
    {
      "name":"red3",
      "hex":"#cd0000"
    },
    {
      "name":"gray18",
      "hex":"#2e2e2e"
    },
    {
      "name":"grey18",
      "hex":"#2e2e2e"
    },
    {
      "name":"darkviolet",
      "hex":"#9400d3"
    },
    {
      "name":"dark violet",
      "hex":"#9400d3"
    },
    {
      "name":"purple4",
      "hex":"#551a8b"
    },
    {
      "name":"gray19",
      "hex":"#303030"
    },
    {
      "name":"grey19",
      "hex":"#303030"
    },
    {
      "name":"firebrick4",
      "hex":"#8b1a1a"
    },
    {
      "name":"red2",
      "hex":"#ee0000"
    },
    {
      "name":"gray20",
      "hex":"#333333"
    },
    {
      "name":"grey20",
      "hex":"#333333"
    },
    {
      "name":"gray21",
      "hex":"#363636"
    },
    {
      "name":"grey21",
      "hex":"#363636"
    },
    {
      "name":"red1",
      "hex":"#ff0000"
    },
    {
      "name":"red",
      "hex":"#ff0000"
    },
    {
      "name":"gray22",
      "hex":"#383838"
    },
    {
      "name":"grey22",
      "hex":"#383838"
    },
    {
      "name":"orangered4",
      "hex":"#8b2500"
    },
    {
      "name":"darkorchid4",
      "hex":"#68228b"
    },
    {
      "name":"maroon4",
      "hex":"#8b1c62"
    },
    {
      "name":"brown4",
      "hex":"#8b2323"
    },
    {
      "name":"magenta3",
      "hex":"#cd00cd"
    },
    {
      "name":"gray23",
      "hex":"#3b3b3b"
    },
    {
      "name":"grey23",
      "hex":"#3b3b3b"
    },
    {
      "name":"violetred4",
      "hex":"#8b2252"
    },
    {
      "name":"gray24",
      "hex":"#3d3d3d"
    },
    {
      "name":"grey24",
      "hex":"#3d3d3d"
    },
    {
      "name":"deeppink3",
      "hex":"#cd1076"
    },
    {
      "name":"gray25",
      "hex":"#404040"
    },
    {
      "name":"grey25",
      "hex":"#404040"
    },
    {
      "name":"royalblue4",
      "hex":"#27408b"
    },
    {
      "name":"firebrick",
      "hex":"#b22222"
    },
    {
      "name":"gray26",
      "hex":"#424242"
    },
    {
      "name":"grey26",
      "hex":"#424242"
    },
    {
      "name":"mediumvioletred",
      "hex":"#c71585"
    },
    {
      "name":"medium violet red",
      "hex":"#c71585"
    },
    {
      "name":"magenta2",
      "hex":"#ee00ee"
    },
    {
      "name":"slateblue4",
      "hex":"#473c8b"
    },
    {
      "name":"brown",
      "hex":"#a52a2a"
    },
    {
      "name":"purple3",
      "hex":"#7d26cd"
    },
    {
      "name":"darkslateblue",
      "hex":"#483d8b"
    },
    {
      "name":"dark slate blue",
      "hex":"#483d8b"
    },
    {
      "name":"gray27",
      "hex":"#454545"
    },
    {
      "name":"grey27",
      "hex":"#454545"
    },
    {
      "name":"dodgerblue4",
      "hex":"#104e8b"
    },
    {
      "name":"tomato4",
      "hex":"#8b3626"
    },
    {
      "name":"gray28",
      "hex":"#474747"
    },
    {
      "name":"grey28",
      "hex":"#474747"
    },
    {
      "name":"darkgreen",
      "hex":"#006400"
    },
    {
      "name":"dark green",
      "hex":"#006400"
    },
    {
      "name":"darkslategray",
      "hex":"#2f4f4f"
    },
    {
      "name":"darkslategrey",
      "hex":"#2f4f4f"
    },
    {
      "name":"dark slate gray",
      "hex":"#2f4f4f"
    },
    {
      "name":"dark slate grey",
      "hex":"#2f4f4f"
    },
    {
      "name":"magenta1",
      "hex":"#ff00ff"
    },
    {
      "name":"magenta",
      "hex":"#ff00ff"
    },
    {
      "name":"deeppink2",
      "hex":"#ee1289"
    },
    {
      "name":"firebrick3",
      "hex":"#cd2626"
    },
    {
      "name":"gray29",
      "hex":"#4a4a4a"
    },
    {
      "name":"grey29",
      "hex":"#4a4a4a"
    },
    {
      "name":"purple",
      "hex":"#a020f0"
    },
    {
      "name":"indianred4",
      "hex":"#8b3a3a"
    },
    {
      "name":"mediumorchid4",
      "hex":"#7a378b"
    },
    {
      "name":"blueviolet",
      "hex":"#8a2be2"
    },
    {
      "name":"blue violet",
      "hex":"#8a2be2"
    },
    {
      "name":"gray30",
      "hex":"#4d4d4d"
    },
    {
      "name":"grey30",
      "hex":"#4d4d4d"
    },
    {
      "name":"coral4",
      "hex":"#8b3e2f"
    },
    {
      "name":"violetred",
      "hex":"#d02090"
    },
    {
      "name":"violet red",
      "hex":"#d02090"
    },
    {
      "name":"hotpink4",
      "hex":"#8b3a62"
    },
    {
      "name":"maroon",
      "hex":"#b03060"
    },
    {
      "name":"darkorange4",
      "hex":"#8b4500"
    },
    {
      "name":"gray31",
      "hex":"#4f4f4f"
    },
    {
      "name":"grey31",
      "hex":"#4f4f4f"
    },
    {
      "name":"deeppink1",
      "hex":"#ff1493"
    },
    {
      "name":"deeppink",
      "hex":"#ff1493"
    },
    {
      "name":"deep pink",
      "hex":"#ff1493"
    },
    {
      "name":"purple2",
      "hex":"#912cee"
    },
    {
      "name":"saddlebrown",
      "hex":"#8b4513"
    },
    {
      "name":"chocolate4",
      "hex":"#8b4513"
    },
    {
      "name":"saddle brown",
      "hex":"#8b4513"
    },
    {
      "name":"mediumpurple4",
      "hex":"#5d478b"
    },
    {
      "name":"gray32",
      "hex":"#525252"
    },
    {
      "name":"grey32",
      "hex":"#525252"
    },
    {
      "name":"orangered3",
      "hex":"#cd3700"
    },
    {
      "name":"darkorchid",
      "hex":"#9932cc"
    },
    {
      "name":"dark orchid",
      "hex":"#9932cc"
    },
    {
      "name":"sienna4",
      "hex":"#8b4726"
    },
    {
      "name":"darkorchid3",
      "hex":"#9a32cd"
    },
    {
      "name":"maroon3",
      "hex":"#cd2990"
    },
    {
      "name":"brown3",
      "hex":"#cd3333"
    },
    {
      "name":"gray33",
      "hex":"#545454"
    },
    {
      "name":"grey33",
      "hex":"#545454"
    },
    {
      "name":"deepskyblue4",
      "hex":"#00688b"
    },
    {
      "name":"firebrick2",
      "hex":"#ee2c2c"
    },
    {
      "name":"purple1",
      "hex":"#9b30ff"
    },
    {
      "name":"gray34",
      "hex":"#575757"
    },
    {
      "name":"grey34",
      "hex":"#575757"
    },
    {
      "name":"palevioletred4",
      "hex":"#8b475d"
    },
    {
      "name":"violetred3",
      "hex":"#cd3278"
    },
    {
      "name":"salmon4",
      "hex":"#8b4c39"
    },
    {
      "name":"gray35",
      "hex":"#595959"
    },
    {
      "name":"grey35",
      "hex":"#595959"
    },
    {
      "name":"orchid4",
      "hex":"#8b4789"
    },
    {
      "name":"gray36",
      "hex":"#5c5c5c"
    },
    {
      "name":"grey36",
      "hex":"#5c5c5c"
    },
    {
      "name":"firebrick1",
      "hex":"#ff3030"
    },
    {
      "name":"steelblue4",
      "hex":"#36648b"
    },
    {
      "name":"orange4",
      "hex":"#8b5a00"
    },
    {
      "name":"gray37",
      "hex":"#5e5e5e"
    },
    {
      "name":"grey37",
      "hex":"#5e5e5e"
    },
    {
      "name":"royalblue3",
      "hex":"#3a5fcd"
    },
    {
      "name":"sienna",
      "hex":"#a0522d"
    },
    {
      "name":"orangered2",
      "hex":"#ee4000"
    },
    {
      "name":"darkorchid2",
      "hex":"#b23aee"
    },
    {
      "name":"lightsalmon4",
      "hex":"#8b5742"
    },
    {
      "name":"maroon2",
      "hex":"#ee30a7"
    },
    {
      "name":"gray38",
      "hex":"#616161"
    },
    {
      "name":"grey38",
      "hex":"#616161"
    },
    {
      "name":"tan4",
      "hex":"#8b5a2b"
    },
    {
      "name":"brown2",
      "hex":"#ee3b3b"
    },
    {
      "name":"darkolivegreen",
      "hex":"#556b2f"
    },
    {
      "name":"dark olive green",
      "hex":"#556b2f"
    },
    {
      "name":"gray39",
      "hex":"#636363"
    },
    {
      "name":"grey39",
      "hex":"#636363"
    },
    {
      "name":"green4",
      "hex":"#008b00"
    },
    {
      "name":"slateblue3",
      "hex":"#6959cd"
    },
    {
      "name":"slateblue",
      "hex":"#6a5acd"
    },
    {
      "name":"slate blue",
      "hex":"#6a5acd"
    },
    {
      "name":"gray40",
      "hex":"#666666"
    },
    {
      "name":"grey40",
      "hex":"#666666"
    },
    {
      "name":"violetred2",
      "hex":"#ee3a8c"
    },
    {
      "name":"darkgoldenrod4",
      "hex":"#8b6508"
    },
    {
      "name":"dodgerblue3",
      "hex":"#1874cd"
    },
    {
      "name":"darkorchid1",
      "hex":"#bf3eff"
    },
    {
      "name":"orangered1",
      "hex":"#ff4500"
    },
    {
      "name":"orangered",
      "hex":"#ff4500"
    },
    {
      "name":"orange red",
      "hex":"#ff4500"
    },
    {
      "name":"tomato3",
      "hex":"#cd4f39"
    },
    {
      "name":"maroon1",
      "hex":"#ff34b3"
    },
    {
      "name":"springgreen4",
      "hex":"#008b45"
    },
    {
      "name":"brown1",
      "hex":"#ff4040"
    },
    {
      "name":"lightpink4",
      "hex":"#8b5f65"
    },
    {
      "name":"dimgray",
      "hex":"#696969"
    },
    {
      "name":"dimgrey",
      "hex":"#696969"
    },
    {
      "name":"dim gray",
      "hex":"#696969"
    },
    {
      "name":"dim grey",
      "hex":"#696969"
    },
    {
      "name":"gray41",
      "hex":"#696969"
    },
    {
      "name":"grey41",
      "hex":"#696969"
    },
    {
      "name":"royalblue",
      "hex":"#4169e1"
    },
    {
      "name":"royal blue",
      "hex":"#4169e1"
    },
    {
      "name":"skyblue4",
      "hex":"#4a708b"
    },
    {
      "name":"turquoise4",
      "hex":"#00868b"
    },
    {
      "name":"goldenrod4",
      "hex":"#8b6914"
    },
    {
      "name":"gray42",
      "hex":"#6b6b6b"
    },
    {
      "name":"grey42",
      "hex":"#6b6b6b"
    },
    {
      "name":"pink4",
      "hex":"#8b636c"
    },
    {
      "name":"forestgreen",
      "hex":"#228b22"
    },
    {
      "name":"forest green",
      "hex":"#228b22"
    },
    {
      "name":"violetred1",
      "hex":"#ff3e96"
    },
    {
      "name":"darkcyan",
      "hex":"#008b8b"
    },
    {
      "name":"cyan4",
      "hex":"#008b8b"
    },
    {
      "name":"dark cyan",
      "hex":"#008b8b"
    },
    {
      "name":"gray43",
      "hex":"#6e6e6e"
    },
    {
      "name":"grey43",
      "hex":"#6e6e6e"
    },
    {
      "name":"royalblue2",
      "hex":"#436eee"
    },
    {
      "name":"indianred3",
      "hex":"#cd5555"
    },
    {
      "name":"mediumorchid3",
      "hex":"#b452cd"
    },
    {
      "name":"gray44",
      "hex":"#707070"
    },
    {
      "name":"grey44",
      "hex":"#707070"
    },
    {
      "name":"rosybrown4",
      "hex":"#8b6969"
    },
    {
      "name":"plum4",
      "hex":"#8b668b"
    },
    {
      "name":"gold4",
      "hex":"#8b7500"
    },
    {
      "name":"coral3",
      "hex":"#cd5b45"
    },
    {
      "name":"chartreuse4",
      "hex":"#458b00"
    },
    {
      "name":"gray45",
      "hex":"#737373"
    },
    {
      "name":"grey45",
      "hex":"#737373"
    },
    {
      "name":"seagreen4",
      "hex":"#2e8b57"
    },
    {
      "name":"seagreen",
      "hex":"#2e8b57"
    },
    {
      "name":"sea green",
      "hex":"#2e8b57"
    },
    {
      "name":"mediumorchid",
      "hex":"#ba55d3"
    },
    {
      "name":"medium orchid",
      "hex":"#ba55d3"
    },
    {
      "name":"indianred",
      "hex":"#cd5c5c"
    },
    {
      "name":"indian red",
      "hex":"#cd5c5c"
    },
    {
      "name":"darkorange3",
      "hex":"#cd6600"
    },
    {
      "name":"slateblue2",
      "hex":"#7a67ee"
    },
    {
      "name":"gray46",
      "hex":"#757575"
    },
    {
      "name":"grey46",
      "hex":"#757575"
    },
    {
      "name":"mediumslateblue",
      "hex":"#7b68ee"
    },
    {
      "name":"medium slate blue",
      "hex":"#7b68ee"
    },
    {
      "name":"burlywood4",
      "hex":"#8b7355"
    },
    {
      "name":"royalblue1",
      "hex":"#4876ff"
    },
    {
      "name":"mediumpurple3",
      "hex":"#8968cd"
    },
    {
      "name":"lightskyblue4",
      "hex":"#607b8b"
    },
    {
      "name":"chocolate3",
      "hex":"#cd661d"
    },
    {
      "name":"dodgerblue2",
      "hex":"#1c86ee"
    },
    {
      "name":"gray47",
      "hex":"#787878"
    },
    {
      "name":"grey47",
      "hex":"#787878"
    },
    {
      "name":"steelblue",
      "hex":"#4682b4"
    },
    {
      "name":"steel blue",
      "hex":"#4682b4"
    },
    {
      "name":"slategray4",
      "hex":"#6c7b8b"
    },
    {
      "name":"tomato2",
      "hex":"#ee5c42"
    },
    {
      "name":"lightsteelblue4",
      "hex":"#6e7b8b"
    },
    {
      "name":"chocolate",
      "hex":"#d2691e"
    },
    {
      "name":"peachpuff4",
      "hex":"#8b7765"
    },
    {
      "name":"gray48",
      "hex":"#7a7a7a"
    },
    {
      "name":"grey48",
      "hex":"#7a7a7a"
    },
    {
      "name":"sienna3",
      "hex":"#cd6839"
    },
    {
      "name":"aquamarine4",
      "hex":"#458b74"
    },
    {
      "name":"hotpink3",
      "hex":"#cd6090"
    },
    {
      "name":"navajowhite4",
      "hex":"#8b795e"
    },
    {
      "name":"palegreen4",
      "hex":"#548b54"
    },
    {
      "name":"cadetblue4",
      "hex":"#53868b"
    },
    {
      "name":"olivedrab4",
      "hex":"#698b22"
    },
    {
      "name":"deepskyblue3",
      "hex":"#009acd"
    },
    {
      "name":"gray49",
      "hex":"#7d7d7d"
    },
    {
      "name":"grey49",
      "hex":"#7d7d7d"
    },
    {
      "name":"slateblue1",
      "hex":"#836fff"
    },
    {
      "name":"slategray",
      "hex":"#708090"
    },
    {
      "name":"slategrey",
      "hex":"#708090"
    },
    {
      "name":"slate gray",
      "hex":"#708090"
    },
    {
      "name":"slate grey",
      "hex":"#708090"
    },
    {
      "name":"lightblue4",
      "hex":"#68838b"
    },
    {
      "name":"lightslateblue",
      "hex":"#8470ff"
    },
    {
      "name":"light slate blue",
      "hex":"#8470ff"
    },
    {
      "name":"bisque4",
      "hex":"#8b7d6b"
    },
    {
      "name":"olivedrab",
      "hex":"#6b8e23"
    },
    {
      "name":"olive drab",
      "hex":"#6b8e23"
    },
    {
      "name":"darkslategray4",
      "hex":"#528b8b"
    },
    {
      "name":"gray50",
      "hex":"#7f7f7f"
    },
    {
      "name":"grey50",
      "hex":"#7f7f7f"
    },
    {
      "name":"wheat4",
      "hex":"#8b7e66"
    },
    {
      "name":"mediumpurple",
      "hex":"#9370db"
    },
    {
      "name":"medium purple",
      "hex":"#9370db"
    },
    {
      "name":"darkolivegreen4",
      "hex":"#6e8b3d"
    },
    {
      "name":"lightgoldenrod4",
      "hex":"#8b814c"
    },
    {
      "name":"thistle4",
      "hex":"#8b7b8b"
    },
    {
      "name":"dodgerblue1",
      "hex":"#1e90ff"
    },
    {
      "name":"dodgerblue",
      "hex":"#1e90ff"
    },
    {
      "name":"dodger blue",
      "hex":"#1e90ff"
    },
    {
      "name":"mistyrose4",
      "hex":"#8b7d7b"
    },
    {
      "name":"palevioletred3",
      "hex":"#cd6889"
    },
    {
      "name":"indianred2",
      "hex":"#ee6363"
    },
    {
      "name":"yellow4",
      "hex":"#8b8b00"
    },
    {
      "name":"darkseagreen4",
      "hex":"#698b69"
    },
    {
      "name":"mediumorchid2",
      "hex":"#d15fee"
    },
    {
      "name":"salmon3",
      "hex":"#cd7054"
    },
    {
      "name":"gray51",
      "hex":"#828282"
    },
    {
      "name":"grey51",
      "hex":"#828282"
    },
    {
      "name":"tomato1",
      "hex":"#ff6347"
    },
    {
      "name":"tomato",
      "hex":"#ff6347"
    },
    {
      "name":"khaki4",
      "hex":"#8b864e"
    },
    {
      "name":"paleturquoise4",
      "hex":"#668b8b"
    },
    {
      "name":"antiquewhite4",
      "hex":"#8b8378"
    },
    {
      "name":"coral2",
      "hex":"#ee6a50"
    },
    {
      "name":"lavenderblush4",
      "hex":"#8b8386"
    },
    {
      "name":"gray52",
      "hex":"#858585"
    },
    {
      "name":"grey52",
      "hex":"#858585"
    },
    {
      "name":"orchid3",
      "hex":"#cd69c9"
    },
    {
      "name":"lightslategray",
      "hex":"#778899"
    },
    {
      "name":"lightslategrey",
      "hex":"#778899"
    },
    {
      "name":"light slate gray",
      "hex":"#778899"
    },
    {
      "name":"light slate grey",
      "hex":"#778899"
    },
    {
      "name":"seashell4",
      "hex":"#8b8682"
    },
    {
      "name":"darkorange2",
      "hex":"#ee7600"
    },
    {
      "name":"gray53",
      "hex":"#878787"
    },
    {
      "name":"grey53",
      "hex":"#878787"
    },
    {
      "name":"lightcyan4",
      "hex":"#7a8b8b"
    },
    {
      "name":"cornsilk4",
      "hex":"#8b8878"
    },
    {
      "name":"lemonchiffon4",
      "hex":"#8b8970"
    },
    {
      "name":"darkgoldenrod",
      "hex":"#b8860b"
    },
    {
      "name":"dark goldenrod",
      "hex":"#b8860b"
    },
    {
      "name":"honeydew4",
      "hex":"#838b83"
    },
    {
      "name":"palevioletred",
      "hex":"#db7093"
    },
    {
      "name":"pale violet red",
      "hex":"#db7093"
    },
    {
      "name":"azure4",
      "hex":"#838b8b"
    },
    {
      "name":"chocolate2",
      "hex":"#ee7621"
    },
    {
      "name":"snow4",
      "hex":"#8b8989"
    },
    {
      "name":"steelblue3",
      "hex":"#4f94cd"
    },
    {
      "name":"mediumpurple2",
      "hex":"#9f79ee"
    },
    {
      "name":"indianred1",
      "hex":"#ff6a6a"
    },
    {
      "name":"lightyellow4",
      "hex":"#8b8b7a"
    },
    {
      "name":"gray54",
      "hex":"#8a8a8a"
    },
    {
      "name":"grey54",
      "hex":"#8a8a8a"
    },
    {
      "name":"ivory4",
      "hex":"#8b8b83"
    },
    {
      "name":"hotpink2",
      "hex":"#ee6aa7"
    },
    {
      "name":"orange3",
      "hex":"#cd8500"
    },
    {
      "name":"mediumorchid1",
      "hex":"#e066ff"
    },
    {
      "name":"gray55",
      "hex":"#8c8c8c"
    },
    {
      "name":"grey55",
      "hex":"#8c8c8c"
    },
    {
      "name":"orchid",
      "hex":"#da70d6"
    },
    {
      "name":"sienna2",
      "hex":"#ee7942"
    },
    {
      "name":"coral1",
      "hex":"#ff7256"
    },
    {
      "name":"hotpink",
      "hex":"#ff69b4"
    },
    {
      "name":"hot pink",
      "hex":"#ff69b4"
    },
    {
      "name":"lightsalmon3",
      "hex":"#cd8162"
    },
    {
      "name":"gray56",
      "hex":"#8f8f8f"
    },
    {
      "name":"grey56",
      "hex":"#8f8f8f"
    },
    {
      "name":"peru",
      "hex":"#cd853f"
    },
    {
      "name":"tan3",
      "hex":"#cd853f"
    },
    {
      "name":"deepskyblue2",
      "hex":"#00b2ee"
    },
    {
      "name":"cadetblue",
      "hex":"#5f9ea0"
    },
    {
      "name":"cadet blue",
      "hex":"#5f9ea0"
    },
    {
      "name":"cornflowerblue",
      "hex":"#6495ed"
    },
    {
      "name":"cornflower blue",
      "hex":"#6495ed"
    },
    {
      "name":"gray57",
      "hex":"#919191"
    },
    {
      "name":"grey57",
      "hex":"#919191"
    },
    {
      "name":"darkorange1",
      "hex":"#ff7f00"
    },
    {
      "name":"hotpink1",
      "hex":"#ff6eb4"
    },
    {
      "name":"lightseagreen",
      "hex":"#20b2aa"
    },
    {
      "name":"light sea green",
      "hex":"#20b2aa"
    },
    {
      "name":"green3",
      "hex":"#00cd00"
    },
    {
      "name":"chocolate1",
      "hex":"#ff7f24"
    },
    {
      "name":"mediumpurple1",
      "hex":"#ab82ff"
    },
    {
      "name":"gray58",
      "hex":"#949494"
    },
    {
      "name":"grey58",
      "hex":"#949494"
    },
    {
      "name":"palevioletred2",
      "hex":"#ee799f"
    },
    {
      "name":"mediumseagreen",
      "hex":"#3cb371"
    },
    {
      "name":"medium sea green",
      "hex":"#3cb371"
    },
    {
      "name":"gray59",
      "hex":"#969696"
    },
    {
      "name":"grey59",
      "hex":"#969696"
    },
    {
      "name":"salmon2",
      "hex":"#ee8262"
    },
    {
      "name":"coral",
      "hex":"#ff7f50"
    },
    {
      "name":"darkgoldenrod3",
      "hex":"#cd950c"
    },
    {
      "name":"lightcoral",
      "hex":"#f08080"
    },
    {
      "name":"light coral",
      "hex":"#f08080"
    },
    {
      "name":"sienna1",
      "hex":"#ff8247"
    },
    {
      "name":"rosybrown",
      "hex":"#bc8f8f"
    },
    {
      "name":"rosy brown",
      "hex":"#bc8f8f"
    },
    {
      "name":"salmon",
      "hex":"#fa8072"
    },
    {
      "name":"gray60",
      "hex":"#999999"
    },
    {
      "name":"grey60",
      "hex":"#999999"
    },
    {
      "name":"springgreen3",
      "hex":"#00cd66"
    },
    {
      "name":"darkorange",
      "hex":"#ff8c00"
    },
    {
      "name":"dark orange",
      "hex":"#ff8c00"
    },
    {
      "name":"lightpink3",
      "hex":"#cd8c95"
    },
    {
      "name":"orchid2",
      "hex":"#ee7ae9"
    },
    {
      "name":"deepskyblue1",
      "hex":"#00bfff"
    },
    {
      "name":"deepskyblue",
      "hex":"#00bfff"
    },
    {
      "name":"deep sky blue",
      "hex":"#00bfff"
    },
    {
      "name":"turquoise3",
      "hex":"#00c5cd"
    },
    {
      "name":"gray61",
      "hex":"#9c9c9c"
    },
    {
      "name":"grey61",
      "hex":"#9c9c9c"
    },
    {
      "name":"skyblue3",
      "hex":"#6ca6cd"
    },
    {
      "name":"goldenrod3",
      "hex":"#cd9b1d"
    },
    {
      "name":"gray62",
      "hex":"#9e9e9e"
    },
    {
      "name":"grey62",
      "hex":"#9e9e9e"
    },
    {
      "name":"pink3",
      "hex":"#cd919e"
    },
    {
      "name":"palevioletred1",
      "hex":"#ff82ab"
    },
    {
      "name":"steelblue2",
      "hex":"#5cacee"
    },
    {
      "name":"orange2",
      "hex":"#ee9a00"
    },
    {
      "name":"violet",
      "hex":"#ee82ee"
    },
    {
      "name":"limegreen",
      "hex":"#32cd32"
    },
    {
      "name":"lime green",
      "hex":"#32cd32"
    },
    {
      "name":"gray63",
      "hex":"#a1a1a1"
    },
    {
      "name":"grey63",
      "hex":"#a1a1a1"
    },
    {
      "name":"cyan3",
      "hex":"#00cdcd"
    },
    {
      "name":"salmon1",
      "hex":"#ff8c69"
    },
    {
      "name":"darkturquoise",
      "hex":"#00ced1"
    },
    {
      "name":"dark turquoise",
      "hex":"#00ced1"
    },
    {
      "name":"gray64",
      "hex":"#a3a3a3"
    },
    {
      "name":"grey64",
      "hex":"#a3a3a3"
    },
    {
      "name":"lightsalmon2",
      "hex":"#ee9572"
    },
    {
      "name":"darksalmon",
      "hex":"#e9967a"
    },
    {
      "name":"dark salmon",
      "hex":"#e9967a"
    },
    {
      "name":"rosybrown3",
      "hex":"#cd9b9b"
    },
    {
      "name":"plum3",
      "hex":"#cd96cd"
    },
    {
      "name":"orchid1",
      "hex":"#ff83fa"
    },
    {
      "name":"gray65",
      "hex":"#a6a6a6"
    },
    {
      "name":"grey65",
      "hex":"#a6a6a6"
    },
    {
      "name":"tan2",
      "hex":"#ee9a49"
    },
    {
      "name":"goldenrod",
      "hex":"#daa520"
    },
    {
      "name":"gold3",
      "hex":"#cdad00"
    },
    {
      "name":"gray66",
      "hex":"#a8a8a8"
    },
    {
      "name":"grey66",
      "hex":"#a8a8a8"
    },
    {
      "name":"chartreuse3",
      "hex":"#66cd00"
    },
    {
      "name":"darkgray",
      "hex":"#a9a9a9"
    },
    {
      "name":"darkgrey",
      "hex":"#a9a9a9"
    },
    {
      "name":"dark gray",
      "hex":"#a9a9a9"
    },
    {
      "name":"dark grey",
      "hex":"#a9a9a9"
    },
    {
      "name":"seagreen3",
      "hex":"#43cd80"
    },
    {
      "name":"green2",
      "hex":"#00ee00"
    },
    {
      "name":"gray67",
      "hex":"#ababab"
    },
    {
      "name":"grey67",
      "hex":"#ababab"
    },
    {
      "name":"steelblue1",
      "hex":"#63b8ff"
    },
    {
      "name":"orange1",
      "hex":"#ffa500"
    },
    {
      "name":"orange",
      "hex":"#ffa500"
    },
    {
      "name":"gray68",
      "hex":"#adadad"
    },
    {
      "name":"grey68",
      "hex":"#adadad"
    },
    {
      "name":"burlywood3",
      "hex":"#cdaa7d"
    },
    {
      "name":"lightskyblue3",
      "hex":"#8db6cd"
    },
    {
      "name":"darkseagreen",
      "hex":"#8fbc8f"
    },
    {
      "name":"dark sea green",
      "hex":"#8fbc8f"
    },
    {
      "name":"darkgoldenrod2",
      "hex":"#eead0e"
    },
    {
      "name":"gray69",
      "hex":"#b0b0b0"
    },
    {
      "name":"grey69",
      "hex":"#b0b0b0"
    },
    {
      "name":"sandybrown",
      "hex":"#f4a460"
    },
    {
      "name":"sandy brown",
      "hex":"#f4a460"
    },
    {
      "name":"plum",
      "hex":"#dda0dd"
    },
    {
      "name":"lightsalmon1",
      "hex":"#ffa07a"
    },
    {
      "name":"lightsalmon",
      "hex":"#ffa07a"
    },
    {
      "name":"light salmon",
      "hex":"#ffa07a"
    },
    {
      "name":"tan1",
      "hex":"#ffa54f"
    },
    {
      "name":"lightsteelblue3",
      "hex":"#a2b5cd"
    },
    {
      "name":"springgreen2",
      "hex":"#00ee76"
    },
    {
      "name":"slategray3",
      "hex":"#9fb6cd"
    },
    {
      "name":"darkkhaki",
      "hex":"#bdb76b"
    },
    {
      "name":"dark khaki",
      "hex":"#bdb76b"
    },
    {
      "name":"lightpink2",
      "hex":"#eea2ad"
    },
    {
      "name":"gray70",
      "hex":"#b3b3b3"
    },
    {
      "name":"grey70",
      "hex":"#b3b3b3"
    },
    {
      "name":"peachpuff3",
      "hex":"#cdaf95"
    },
    {
      "name":"mediumturquoise",
      "hex":"#48d1cc"
    },
    {
      "name":"medium turquoise",
      "hex":"#48d1cc"
    },
    {
      "name":"mediumaquamarine",
      "hex":"#66cdaa"
    },
    {
      "name":"aquamarine3",
      "hex":"#66cdaa"
    },
    {
      "name":"medium aquamarine",
      "hex":"#66cdaa"
    },
    {
      "name":"turquoise2",
      "hex":"#00e5ee"
    },
    {
      "name":"gray71",
      "hex":"#b5b5b5"
    },
    {
      "name":"grey71",
      "hex":"#b5b5b5"
    },
    {
      "name":"skyblue2",
      "hex":"#7ec0ee"
    },
    {
      "name":"cadetblue3",
      "hex":"#7ac5cd"
    },
    {
      "name":"navajowhite3",
      "hex":"#cdb38b"
    },
    {
      "name":"goldenrod2",
      "hex":"#eeb422"
    },
    {
      "name":"palegreen3",
      "hex":"#7ccd7c"
    },
    {
      "name":"green1",
      "hex":"#00ff00"
    },
    {
      "name":"green",
      "hex":"#00ff00"
    },
    {
      "name":"olivedrab3",
      "hex":"#9acd32"
    },
    {
      "name":"yellowgreen",
      "hex":"#9acd32"
    },
    {
      "name":"yellow green",
      "hex":"#9acd32"
    },
    {
      "name":"tan",
      "hex":"#d2b48c"
    },
    {
      "name":"gray72",
      "hex":"#b8b8b8"
    },
    {
      "name":"grey72",
      "hex":"#b8b8b8"
    },
    {
      "name":"pink2",
      "hex":"#eea9b8"
    },
    {
      "name":"lightblue3",
      "hex":"#9ac0cd"
    },
    {
      "name":"bisque3",
      "hex":"#cdb79e"
    },
    {
      "name":"gray73",
      "hex":"#bababa"
    },
    {
      "name":"grey73",
      "hex":"#bababa"
    },
    {
      "name":"darkslategray3",
      "hex":"#79cdcd"
    },
    {
      "name":"cyan2",
      "hex":"#00eeee"
    },
    {
      "name":"wheat3",
      "hex":"#cdba96"
    },
    {
      "name":"mistyrose3",
      "hex":"#cdb7b5"
    },
    {
      "name":"darkolivegreen3",
      "hex":"#a2cd5a"
    },
    {
      "name":"lightgoldenrod3",
      "hex":"#cdbe70"
    },
    {
      "name":"darkgoldenrod1",
      "hex":"#ffb90f"
    },
    {
      "name":"thistle3",
      "hex":"#cdb5cd"
    },
    {
      "name":"burlywood",
      "hex":"#deb887"
    },
    {
      "name":"turquoise",
      "hex":"#40e0d0"
    },
    {
      "name":"gray74",
      "hex":"#bdbdbd"
    },
    {
      "name":"grey74",
      "hex":"#bdbdbd"
    },
    {
      "name":"mediumspringgreen",
      "hex":"#00fa9a"
    },
    {
      "name":"medium spring green",
      "hex":"#00fa9a"
    },
    {
      "name":"gray",
      "hex":"#bebebe"
    },
    {
      "name":"grey",
      "hex":"#bebebe"
    },
    {
      "name":"yellow3",
      "hex":"#cdcd00"
    },
    {
      "name":"darkseagreen3",
      "hex":"#9bcd9b"
    },
    {
      "name":"gray75",
      "hex":"#bfbfbf"
    },
    {
      "name":"grey75",
      "hex":"#bfbfbf"
    },
    {
      "name":"springgreen1",
      "hex":"#00ff7f"
    },
    {
      "name":"springgreen",
      "hex":"#00ff7f"
    },
    {
      "name":"spring green",
      "hex":"#00ff7f"
    },
    {
      "name":"lightpink1",
      "hex":"#ffaeb9"
    },
    {
      "name":"plum2",
      "hex":"#eeaeee"
    },
    {
      "name":"rosybrown2",
      "hex":"#eeb4b4"
    },
    {
      "name":"skyblue",
      "hex":"#87ceeb"
    },
    {
      "name":"sky blue",
      "hex":"#87ceeb"
    },
    {
      "name":"paleturquoise3",
      "hex":"#96cdcd"
    },
    {
      "name":"khaki3",
      "hex":"#cdc673"
    },
    {
      "name":"antiquewhite3",
      "hex":"#cdc0b0"
    },
    {
      "name":"lightsteelblue",
      "hex":"#b0c4de"
    },
    {
      "name":"light steel blue",
      "hex":"#b0c4de"
    },
    {
      "name":"turquoise1",
      "hex":"#00f5ff"
    },
    {
      "name":"gray76",
      "hex":"#c2c2c2"
    },
    {
      "name":"grey76",
      "hex":"#c2c2c2"
    },
    {
      "name":"lightskyblue",
      "hex":"#87cefa"
    },
    {
      "name":"light sky blue",
      "hex":"#87cefa"
    },
    {
      "name":"gold2",
      "hex":"#eec900"
    },
    {
      "name":"skyblue1",
      "hex":"#87ceff"
    },
    {
      "name":"goldenrod1",
      "hex":"#ffc125"
    },
    {
      "name":"chartreuse2",
      "hex":"#76ee00"
    },
    {
      "name":"lavenderblush3",
      "hex":"#cdc1c5"
    },
    {
      "name":"gray77",
      "hex":"#c4c4c4"
    },
    {
      "name":"grey77",
      "hex":"#c4c4c4"
    },
    {
      "name":"seagreen2",
      "hex":"#4eee94"
    },
    {
      "name":"pink1",
      "hex":"#ffb5c5"
    },
    {
      "name":"thistle",
      "hex":"#d8bfd8"
    },
    {
      "name":"seashell3",
      "hex":"#cdc5bf"
    },
    {
      "name":"lightpink",
      "hex":"#ffb6c1"
    },
    {
      "name":"light pink",
      "hex":"#ffb6c1"
    },
    {
      "name":"gray78",
      "hex":"#c7c7c7"
    },
    {
      "name":"grey78",
      "hex":"#c7c7c7"
    },
    {
      "name":"lemonchiffon3",
      "hex":"#cdc9a5"
    },
    {
      "name":"cornsilk3",
      "hex":"#cdc8b1"
    },
    {
      "name":"lightcyan3",
      "hex":"#b4cdcd"
    },
    {
      "name":"cyan1",
      "hex":"#00ffff"
    },
    {
      "name":"cyan",
      "hex":"#00ffff"
    },
    {
      "name":"gray79",
      "hex":"#c9c9c9"
    },
    {
      "name":"grey79",
      "hex":"#c9c9c9"
    },
    {
      "name":"honeydew3",
      "hex":"#c1cdc1"
    },
    {
      "name":"snow3",
      "hex":"#cdc9c9"
    },
    {
      "name":"burlywood2",
      "hex":"#eec591"
    },
    {
      "name":"azure3",
      "hex":"#c1cdcd"
    },
    {
      "name":"lightskyblue2",
      "hex":"#a4d3ee"
    },
    {
      "name":"lightyellow3",
      "hex":"#cdcdb4"
    },
    {
      "name":"gray80",
      "hex":"#cccccc"
    },
    {
      "name":"grey80",
      "hex":"#cccccc"
    },
    {
      "name":"ivory3",
      "hex":"#cdcdc1"
    },
    {
      "name":"rosybrown1",
      "hex":"#ffc1c1"
    },
    {
      "name":"pink",
      "hex":"#ffc0cb"
    },
    {
      "name":"plum1",
      "hex":"#ffbbff"
    },
    {
      "name":"lawngreen",
      "hex":"#7cfc00"
    },
    {
      "name":"lawn green",
      "hex":"#7cfc00"
    },
    {
      "name":"gray81",
      "hex":"#cfcfcf"
    },
    {
      "name":"grey81",
      "hex":"#cfcfcf"
    },
    {
      "name":"lightsteelblue2",
      "hex":"#bcd2ee"
    },
    {
      "name":"slategray2",
      "hex":"#b9d3ee"
    },
    {
      "name":"lightblue",
      "hex":"#add8e6"
    },
    {
      "name":"light blue",
      "hex":"#add8e6"
    },
    {
      "name":"gold1",
      "hex":"#ffd700"
    },
    {
      "name":"gold",
      "hex":"#ffd700"
    },
    {
      "name":"peachpuff2",
      "hex":"#eecbad"
    },
    {
      "name":"gray82",
      "hex":"#d1d1d1"
    },
    {
      "name":"grey82",
      "hex":"#d1d1d1"
    },
    {
      "name":"chartreuse1",
      "hex":"#7fff00"
    },
    {
      "name":"chartreuse",
      "hex":"#7fff00"
    },
    {
      "name":"aquamarine2",
      "hex":"#76eec6"
    },
    {
      "name":"navajowhite2",
      "hex":"#eecfa1"
    },
    {
      "name":"lightgray",
      "hex":"#d3d3d3"
    },
    {
      "name":"lightgrey",
      "hex":"#d3d3d3"
    },
    {
      "name":"light gray",
      "hex":"#d3d3d3"
    },
    {
      "name":"light grey",
      "hex":"#d3d3d3"
    },
    {
      "name":"cadetblue2",
      "hex":"#8ee5ee"
    },
    {
      "name":"lightgreen",
      "hex":"#90ee90"
    },
    {
      "name":"palegreen2",
      "hex":"#90ee90"
    },
    {
      "name":"light green",
      "hex":"#90ee90"
    },
    {
      "name":"seagreen1",
      "hex":"#54ff9f"
    },
    {
      "name":"gray83",
      "hex":"#d4d4d4"
    },
    {
      "name":"grey83",
      "hex":"#d4d4d4"
    },
    {
      "name":"olivedrab2",
      "hex":"#b3ee3a"
    },
    {
      "name":"gray84",
      "hex":"#d6d6d6"
    },
    {
      "name":"grey84",
      "hex":"#d6d6d6"
    },
    {
      "name":"powderblue",
      "hex":"#b0e0e6"
    },
    {
      "name":"powder blue",
      "hex":"#b0e0e6"
    },
    {
      "name":"lightblue2",
      "hex":"#b2dfee"
    },
    {
      "name":"bisque2",
      "hex":"#eed5b7"
    },
    {
      "name":"burlywood1",
      "hex":"#ffd39b"
    },
    {
      "name":"gray85",
      "hex":"#d9d9d9"
    },
    {
      "name":"grey85",
      "hex":"#d9d9d9"
    },
    {
      "name":"lightgoldenrod2",
      "hex":"#eedc82"
    },
    {
      "name":"darkslategray2",
      "hex":"#8deeee"
    },
    {
      "name":"lightskyblue1",
      "hex":"#b0e2ff"
    },
    {
      "name":"wheat2",
      "hex":"#eed8ae"
    },
    {
      "name":"darkolivegreen2",
      "hex":"#bcee68"
    },
    {
      "name":"thistle2",
      "hex":"#eed2ee"
    },
    {
      "name":"lightgoldenrod",
      "hex":"#eedd82"
    },
    {
      "name":"light goldenrod",
      "hex":"#eedd82"
    },
    {
      "name":"mistyrose2",
      "hex":"#eed5d2"
    },
    {
      "name":"gray86",
      "hex":"#dbdbdb"
    },
    {
      "name":"grey86",
      "hex":"#dbdbdb"
    },
    {
      "name":"gainsboro",
      "hex":"#dcdcdc"
    },
    {
      "name":"yellow2",
      "hex":"#eeee00"
    },
    {
      "name":"darkseagreen2",
      "hex":"#b4eeb4"
    },
    {
      "name":"gray87",
      "hex":"#dedede"
    },
    {
      "name":"grey87",
      "hex":"#dedede"
    },
    {
      "name":"slategray1",
      "hex":"#c6e2ff"
    },
    {
      "name":"lightsteelblue1",
      "hex":"#cae1ff"
    },
    {
      "name":"greenyellow",
      "hex":"#adff2f"
    },
    {
      "name":"green yellow",
      "hex":"#adff2f"
    },
    {
      "name":"palegreen",
      "hex":"#98fb98"
    },
    {
      "name":"pale green",
      "hex":"#98fb98"
    },
    {
      "name":"peachpuff1",
      "hex":"#ffdab9"
    },
    {
      "name":"peachpuff",
      "hex":"#ffdab9"
    },
    {
      "name":"peach puff",
      "hex":"#ffdab9"
    },
    {
      "name":"wheat",
      "hex":"#f5deb3"
    },
    {
      "name":"gray88",
      "hex":"#e0e0e0"
    },
    {
      "name":"grey88",
      "hex":"#e0e0e0"
    },
    {
      "name":"paleturquoise2",
      "hex":"#aeeeee"
    },
    {
      "name":"paleturquoise",
      "hex":"#afeeee"
    },
    {
      "name":"pale turquoise",
      "hex":"#afeeee"
    },
    {
      "name":"aquamarine1",
      "hex":"#7fffd4"
    },
    {
      "name":"aquamarine",
      "hex":"#7fffd4"
    },
    {
      "name":"khaki2",
      "hex":"#eee685"
    },
    {
      "name":"antiquewhite2",
      "hex":"#eedfcc"
    },
    {
      "name":"navajowhite1",
      "hex":"#ffdead"
    },
    {
      "name":"navajowhite",
      "hex":"#ffdead"
    },
    {
      "name":"navajo white",
      "hex":"#ffdead"
    },
    {
      "name":"khaki",
      "hex":"#f0e68c"
    },
    {
      "name":"cadetblue1",
      "hex":"#98f5ff"
    },
    {
      "name":"palegreen1",
      "hex":"#9aff9a"
    },
    {
      "name":"gray89",
      "hex":"#e3e3e3"
    },
    {
      "name":"grey89",
      "hex":"#e3e3e3"
    },
    {
      "name":"lavenderblush2",
      "hex":"#eee0e5"
    },
    {
      "name":"olivedrab1",
      "hex":"#c0ff3e"
    },
    {
      "name":"palegoldenrod",
      "hex":"#eee8aa"
    },
    {
      "name":"pale goldenrod",
      "hex":"#eee8aa"
    },
    {
      "name":"gray90",
      "hex":"#e5e5e5"
    },
    {
      "name":"grey90",
      "hex":"#e5e5e5"
    },
    {
      "name":"lightblue1",
      "hex":"#bfefff"
    },
    {
      "name":"moccasin",
      "hex":"#ffe4b5"
    },
    {
      "name":"seashell2",
      "hex":"#eee5de"
    },
    {
      "name":"lemonchiffon2",
      "hex":"#eee9bf"
    },
    {
      "name":"cornsilk2",
      "hex":"#eee8cd"
    },
    {
      "name":"bisque1",
      "hex":"#ffe4c4"
    },
    {
      "name":"bisque",
      "hex":"#ffe4c4"
    },
    {
      "name":"lavender",
      "hex":"#e6e6fa"
    },
    {
      "name":"lightcyan2",
      "hex":"#d1eeee"
    },
    {
      "name":"gray91",
      "hex":"#e8e8e8"
    },
    {
      "name":"grey91",
      "hex":"#e8e8e8"
    },
    {
      "name":"wheat1",
      "hex":"#ffe7ba"
    },
    {
      "name":"darkslategray1",
      "hex":"#97ffff"
    },
    {
      "name":"lightgoldenrod1",
      "hex":"#ffec8b"
    },
    {
      "name":"darkolivegreen1",
      "hex":"#caff70"
    },
    {
      "name":"mistyrose1",
      "hex":"#ffe4e1"
    },
    {
      "name":"mistyrose",
      "hex":"#ffe4e1"
    },
    {
      "name":"misty rose",
      "hex":"#ffe4e1"
    },
    {
      "name":"thistle1",
      "hex":"#ffe1ff"
    },
    {
      "name":"honeydew2",
      "hex":"#e0eee0"
    },
    {
      "name":"snow2",
      "hex":"#eee9e9"
    },
    {
      "name":"gray92",
      "hex":"#ebebeb"
    },
    {
      "name":"grey92",
      "hex":"#ebebeb"
    },
    {
      "name":"azure2",
      "hex":"#e0eeee"
    },
    {
      "name":"lightyellow2",
      "hex":"#eeeed1"
    },
    {
      "name":"yellow1",
      "hex":"#ffff00"
    },
    {
      "name":"yellow",
      "hex":"#ffff00"
    },
    {
      "name":"antiquewhite",
      "hex":"#faebd7"
    },
    {
      "name":"antique white",
      "hex":"#faebd7"
    },
    {
      "name":"ivory2",
      "hex":"#eeeee0"
    },
    {
      "name":"gray93",
      "hex":"#ededed"
    },
    {
      "name":"grey93",
      "hex":"#ededed"
    },
    {
      "name":"blanchedalmond",
      "hex":"#ffebcd"
    },
    {
      "name":"blanched almond",
      "hex":"#ffebcd"
    },
    {
      "name":"darkseagreen1",
      "hex":"#c1ffc1"
    },
    {
      "name":"gray94",
      "hex":"#f0f0f0"
    },
    {
      "name":"grey94",
      "hex":"#f0f0f0"
    },
    {
      "name":"khaki1",
      "hex":"#fff68f"
    },
    {
      "name":"papayawhip",
      "hex":"#ffefd5"
    },
    {
      "name":"papaya whip",
      "hex":"#ffefd5"
    },
    {
      "name":"paleturquoise1",
      "hex":"#bbffff"
    },
    {
      "name":"antiquewhite1",
      "hex":"#ffefdb"
    },
    {
      "name":"linen",
      "hex":"#faf0e6"
    },
    {
      "name":"gray95",
      "hex":"#f2f2f2"
    },
    {
      "name":"grey95",
      "hex":"#f2f2f2"
    },
    {
      "name":"beige",
      "hex":"#f5f5dc"
    },
    {
      "name":"lavenderblush1",
      "hex":"#fff0f5"
    },
    {
      "name":"lavenderblush",
      "hex":"#fff0f5"
    },
    {
      "name":"lavender blush",
      "hex":"#fff0f5"
    },
    {
      "name":"whitesmoke",
      "hex":"#f5f5f5"
    },
    {
      "name":"gray96",
      "hex":"#f5f5f5"
    },
    {
      "name":"grey96",
      "hex":"#f5f5f5"
    },
    {
      "name":"white smoke",
      "hex":"#f5f5f5"
    },
    {
      "name":"oldlace",
      "hex":"#fdf5e6"
    },
    {
      "name":"old lace",
      "hex":"#fdf5e6"
    },
    {
      "name":"seashell1",
      "hex":"#fff5ee"
    },
    {
      "name":"seashell",
      "hex":"#fff5ee"
    },
    {
      "name":"aliceblue",
      "hex":"#f0f8ff"
    },
    {
      "name":"alice blue",
      "hex":"#f0f8ff"
    },
    {
      "name":"gray97",
      "hex":"#f7f7f7"
    },
    {
      "name":"grey97",
      "hex":"#f7f7f7"
    },
    {
      "name":"lightgoldenrodyellow",
      "hex":"#fafad2"
    },
    {
      "name":"light goldenrod yellow",
      "hex":"#fafad2"
    },
    {
      "name":"cornsilk1",
      "hex":"#fff8dc"
    },
    {
      "name":"cornsilk",
      "hex":"#fff8dc"
    },
    {
      "name":"lemonchiffon1",
      "hex":"#fffacd"
    },
    {
      "name":"lemonchiffon",
      "hex":"#fffacd"
    },
    {
      "name":"lemon chiffon",
      "hex":"#fffacd"
    },
    {
      "name":"lightcyan1",
      "hex":"#e0ffff"
    },
    {
      "name":"lightcyan",
      "hex":"#e0ffff"
    },
    {
      "name":"light cyan",
      "hex":"#e0ffff"
    },
    {
      "name":"ghostwhite",
      "hex":"#f8f8ff"
    },
    {
      "name":"ghost white",
      "hex":"#f8f8ff"
    },
    {
      "name":"gray98",
      "hex":"#fafafa"
    },
    {
      "name":"grey98",
      "hex":"#fafafa"
    },
    {
      "name":"floralwhite",
      "hex":"#fffaf0"
    },
    {
      "name":"floral white",
      "hex":"#fffaf0"
    },
    {
      "name":"honeydew1",
      "hex":"#f0fff0"
    },
    {
      "name":"honeydew",
      "hex":"#f0fff0"
    },
    {
      "name":"snow1",
      "hex":"#fffafa"
    },
    {
      "name":"snow",
      "hex":"#fffafa"
    },
    {
      "name":"azure1",
      "hex":"#f0ffff"
    },
    {
      "name":"azure",
      "hex":"#f0ffff"
    },
    {
      "name":"gray99",
      "hex":"#fcfcfc"
    },
    {
      "name":"grey99",
      "hex":"#fcfcfc"
    },
    {
      "name":"mintcream",
      "hex":"#f5fffa"
    },
    {
      "name":"mint cream",
      "hex":"#f5fffa"
    },
    {
      "name":"lightyellow1",
      "hex":"#ffffe0"
    },
    {
      "name":"lightyellow",
      "hex":"#ffffe0"
    },
    {
      "name":"light yellow",
      "hex":"#ffffe0"
    },
    {
      "name":"ivory1",
      "hex":"#fffff0"
    },
    {
      "name":"ivory",
      "hex":"#fffff0"
    },
    {
      "name":"gray100",
      "hex":"#ffffff"
    },
    {
      "name":"grey100",
      "hex":"#ffffff"
    },
    {
      "name":"white",
      "hex":"#ffffff"
    }
  ]
